@@ -9,8 +9,8 @@ function (x, enum.plots = FALSE, ...)
   old.par <- par (mfrow = c (1,3))
 
   plot (x$x, main.pre = main.pre[1], ...)
-  plot.DiscrFact.p2 (x, main.pre = main.pre[2], ...)
-  plot.DiscrFact.p3 (x, main.pre = main.pre[3], ...)  
+  plot_DiscrFact_p2 (x, main.pre = main.pre[2], ...)
+  plot_DiscrFact_p3 (x, main.pre = main.pre[3], ...)  
 
   par (old.par)
 }
